import 'dart:collection';
import 'dart:convert';

import 'package:flutter/material.dart';
import 'package:flutter_html/flutter_html.dart';
import 'package:flutter_swiper_plus/flutter_swiper_plus.dart';
import 'package:pull_to_refresh/pull_to_refresh.dart';

import '../Iconfont.dart';
import '../dio/APIs.dart';
import '../dio/HttpUtils.dart';
import '../utils/Global.dart';
import '../utils/TimeUtils.dart';

class MyCollection extends StatefulWidget {
  const MyCollection({super.key});

  @override
  State<StatefulWidget> createState() {
    return MyCollectionState();
  }
}

class MyCollectionState extends State {
  bool isloading = false;

  bool isRefresh = false;
  RefreshController refreshController = RefreshController();


  int pageNo = 1;
  int pageSize = 15;

  Map datamap = HashMap();
  @override
  void initState() {
    super.initState();
    getNewsList();
  }


  //获取新闻列表
  getNewsList() async {
    HttpUtils.postJSON(context, APIs.queryMyCollectionArticle, {
      "pageNo": pageNo,
      "pageSize": pageSize,
      "channelId": "7,9,10,11,12,14",
      "hasInclude": false,
      "randomKey": "0.33621082370012556",
      "statusKey":"2",
      "token": await Global.getData("token"),
      // "title": ""
    }, success: (data) async {
      setState(() {
        isRefresh = true;
        datamap = data;
      });
    }, fail: (code, msg) {});
  }
  void setonTap(String id) async {
    Global.openUrl(context,"/h5View/detail?id=$id&token=${await Global.getData("token")}");
  }
  @override
  Widget build(BuildContext context) {
    return Scaffold(
        appBar: AppBar(
          centerTitle: false,
          backgroundColor: Colors.white,
          title: const Text(
            "我的收藏",
            style: TextStyle(color: Colors.black, fontSize: 18),
          ),
          elevation: 0,
          leading: IconButton(
            icon: const Icon(
              Icons.arrow_back,
              color: Colors.black,
            ),
            onPressed: () {
              Navigator.pop(context);
            },
          ),//标题头阴影  0 为无
        ),
        backgroundColor: Colors.white,

        body:getHinds()
    );
  }
  Widget getHinds() {
    if(!isRefresh){
      return Global.add();
    }else {
      return  ListView.builder(
        //是list列表
          shrinkWrap: true,
          itemCount: datamap["rows"].length ?? 0,
          itemBuilder: (BuildContext context, int index) {
            return getNewsGGType(datamap["rows"][index]["model"]);
          });
      // );
    }
  }

  //新闻公告列表
  Widget getNewsGGType(Map map) {
    if (map["img"]==null||map["img"]=="") {
      return getList1(map["isTop"],map["title"],map["createTime"], map["userName"]??map["articleSource"],map["id"]);
    }else{
      return getList2(map["isTop"],map["title"], map["createTime"],
          map["userName"]??map["articleSource"], json.decode(map["img"])["url"],map["id"]);
    }
  }
  Widget getList1(bool isTop,String title, int time, String username,String id) {
    return GestureDetector(
        child: Column(
          mainAxisAlignment: MainAxisAlignment.start,
          children: [
            Container(
              alignment: Alignment.topLeft,
              margin: const EdgeInsets.only(top: 20,left: 10,right: 10),
              child: Text(
                title,
                overflow: TextOverflow.ellipsis,
                style: const TextStyle(
                    fontSize: 15,
                    color: Color(0xff333333),
                    fontWeight: FontWeight.bold),
              ),
            ),
            Container(
                margin: const EdgeInsets.only(top: 20,left: 10,right: 20),
                child: Row(
                  children: [
                    isTop? Text("置顶  ",//color:Color(APIs.themeColors),
                          style:
                          TextStyle(height: 1.3,fontSize: 13, color: Color(APIs.themeColors),fontWeight: FontWeight.bold),
                        ):const Text(""),
                    Text(username,
                        style:
                        const TextStyle(height: 1.3,fontSize: 13, color: Color(0xff8e8e8e)),
                    ),
                    const Text("   ",
                      style:
                       TextStyle(height: 1.3,fontSize: 13, color: Color(0xff8e8e8e)),
                    ),
                    Text(time == null ? "":
                        TimeUtils.timestampToDateStr(time,true),
                          style: const TextStyle(height: 1.3,fontSize: 13, color: Color(0xff8e8e8e)),
                        ),

                  ],
                )),
            Container(
              margin: const EdgeInsets.only(top: 10),
              width: double.infinity,
              height: 0.5,
              color: const Color(0xffE5E5E5),
            ),
          ],
        ),
        onTap: () {
          setonTap(id);
        });
  }
  Widget getList2(bool isTop,var title, var time, var username, var path,String id) {
    return GestureDetector(
        child: Column(
          children: [
            Row(
              mainAxisAlignment: MainAxisAlignment.spaceBetween,
              crossAxisAlignment: CrossAxisAlignment.center,
              children: [
                Column(
                  mainAxisAlignment: MainAxisAlignment.start,
                  children: [
                    Container(
                      // width: 280,
                      width: Global.getScale(context)*220,
                      alignment: Alignment.topLeft,
                      margin: const EdgeInsets.only(top: 10,left: 10,),
                      child: Text(
                        title??"暂无",
                        style: const TextStyle(
                            fontSize: 15,
                            color: Color(0xff333333),
                            fontWeight: FontWeight.bold),
                      ),
                    ),
                    Container(
                        width: Global.getScale(context)*220,
                        margin: const EdgeInsets.only(top: 10,left: 10,),
                        child: Row(
                          children: [
                            isTop? Expanded(
                                flex: 2,
                                child: Text("置顶  ",
                                  style: TextStyle(height: 1.3,fontSize: 13, color: Color(APIs.themeColors),fontWeight: FontWeight.bold),
                                )):const Text(""),
                            Text(
                                username,
                                style: const TextStyle(
                                    height: 1.3,fontSize: 13, color: Color(0xff8e8e8e)),
                            ),
                            const Text("   ",
                              style:
                              TextStyle(height: 1.3,fontSize: 13, color: Color(0xff8e8e8e)),
                            ),
                            Text(time == null ? "":
                                TimeUtils.timestampToDateStr(time,true),
                                  style: const TextStyle(
                                      height: 1.3,fontSize: 13, color: Color(0xff8e8e8e)),
                                ),

                          ],
                        )),
                  ],
                ),
                Container(
                  padding: const EdgeInsets.only(right: 5, top: 10, bottom: 10),
                  child: Image.network(
                    path,
                    width: Global.getScale(context)*120,
                    height: Global.getScale(context)*80,
                    fit: BoxFit.cover,
                  ),
                ),
              ],
            ),
            Container(
              margin: const EdgeInsets.only(top: 10),
              width: double.infinity,
              height: 0.5,
              color: const Color(0xffE5E5E5),
            ),
          ],
        ),
        onTap: () {
          setonTap(id);
        });
  }
  void _onRefresh() async {
    if (isloading) {//下拉刷新获取网络数据
      // getQueryHome();
    }else{
      refreshController.refreshCompleted();
      refreshController.loadComplete();
    }
    isloading = true;
  }

  void _onLoading() async {
    refreshController.loadComplete();
  }

}