

import 'dart:io';

import 'package:flutter/material.dart';
import 'package:flutter_inappwebview/flutter_inappwebview.dart';
import 'package:url_launcher/url_launcher.dart';




class WebViewNewExample extends StatefulWidget {
  String url;
  String title = "";

  WebViewNewExample(this.url, this.title);

  @override
  WebViewExampleState createState() => WebViewExampleState(url, title);
}

class WebViewExampleState extends State<WebViewNewExample> {
  String murl = "";
  String mtitle = "";

  final GlobalKey webViewKey = GlobalKey();
  InAppWebViewController? webViewController;
  InAppWebViewGroupOptions options = InAppWebViewGroupOptions(
      crossPlatform: InAppWebViewOptions(
        useShouldOverrideUrlLoading: true,
        mediaPlaybackRequiresUserGesture: false,
      ),
      android: AndroidInAppWebViewOptions(
        useHybridComposition: true,
      ),
      ios: IOSInAppWebViewOptions(
        allowsInlineMediaPlayback: true,
      ));

  late PullToRefreshController pullToRefreshController;
  double progress = 0;

  @override
  void initState() {
    super.initState();

    pullToRefreshController = PullToRefreshController(
      options: PullToRefreshOptions(
        color: Colors.blue,
      ),

      onRefresh: () async {
        if (Platform.isAndroid) {
          await AndroidInAppWebViewController.setWebContentsDebuggingEnabled(true);
        }
        if (Platform.isAndroid) {
          webViewController?.reload();
        } else if (Platform.isIOS) {
          webViewController?.loadUrl(
              urlRequest: URLRequest(url: Uri.parse(murl)));
        }
      },
    );
  }
  WebViewExampleState(this.murl, this.mtitle);

  @override
  Widget build(BuildContext context) {
    return Scaffold(
        appBar: AppBar(
          leading: IconButton(
            icon: const Icon(Icons.arrow_back, color: Colors.black),
            onPressed: () {
              Navigator.of(context).pop("fanhui");
            },
          ),
          iconTheme: const IconThemeData(
            color: Color(0xff333333), //修改颜色
          ),
          title: Text(mtitle),
          elevation: 0,
          //去掉阴影
          centerTitle: true, //是否居中
        ),
//        body: InAppWebView(
//          initialData: InAppWebViewInitialData(data: """
// <!DOCTYPE html>
// <html lang="en">
//     <head>
//         <meta charset="UTF-8">
//         <meta name="viewport" content="width=device-width, user-scalable=no, initial-scale=1.0, maximum-scale=1.0, minimum-scale=1.0">
//     </head>
//     <body>
//         <h1>JavaScript Handlers</h1>
//         <script>
//             window.addEventListener("flutterInAppWebViewPlatformReady", function(event) {
//                 window.flutter_inappwebview.callHandler('handlerFoo')
//                   .then(function(result) {
//                     // print to the console the data coming
//                     // from the Flutter side.
//                     console.log(JSON.stringify(result));
//
//                     window.flutter_inappwebview
//                       .callHandler('handlerFooWithArgs', 1, true, ['bar', 5], {foo: 'baz'}, result);
//                 });
//             });
//         </script>
//     </body>
// </html>
//                       """),
//          // initialSettings: settings,
//          onWebViewCreated: (controller) {
//            controller.addJavaScriptHandler(
//                handlerName: 'handlerFoo',
//                callback: (args) {
//                  // return data to the JavaScript side!
//                  return {'bar': 'bar_value', 'baz': 'baz_value'};
//                });
//
//            controller.addJavaScriptHandler(
//                handlerName: 'handlerFooWithArgs',
//                callback: (args) {
//                  print(args);
//                  // it will print: [1, true, [bar, 5], {foo: baz}, {bar: bar_value, baz: baz_value}]
//                });
//          },
//          onConsoleMessage: (controller, consoleMessage) {
//            print(consoleMessage);
//            // it will print: {message: {"bar":"bar_value","baz":"baz_value"}, messageLevel: 1}
//          },
//        ),
        body:InAppWebView(
          key: webViewKey,
          initialUrlRequest: URLRequest(url: Uri.parse(murl)),
          // initialUrlRequest: URLRequest(url: Uri.parse("http://scjoyedu.eicp.net:41002/1.html")),
          initialOptions: options,
          pullToRefreshController: pullToRefreshController,
          onWebViewCreated: (controller) async{
            // controller.addJavaScriptHandler(
            //     handlerName: 'back',
            //     callback: (args) {
            //   return {'bar': 'bar_value', 'baz': 'baz_value'};
            // });
            controller.addJavaScriptHandler(
                handlerName: 'back',
                callback: (args) {
                  Navigator.of(context).pop();
                  // print(args);
                });
          },
          onConsoleMessage: (controller, consoleMessage) {
            print(consoleMessage);

            webViewController = controller;
          },
          onLoadStart: (controller, url) {
            setState(() {
              murl = url.toString();
            });
          },
          androidOnPermissionRequest: (controller, origin, resources) async {
            return PermissionRequestResponse(
                resources: resources,
                action: PermissionRequestResponseAction.GRANT);
          },
          shouldOverrideUrlLoading: (controller, navigationAction) async {
            var uri = navigationAction.request.url!;
            if (!["http", "https", "file", "chrome", "data", "javascript", "about"
            ].contains(uri.scheme)) {
              if (await canLaunch(murl)) {
                // Launch the App
                await launch(
                  murl,
                );
                // and cancel the request
                return NavigationActionPolicy.CANCEL;
              }
            }

            return NavigationActionPolicy.ALLOW;
          },

          onLoadStop: (controller, url) async {
            pullToRefreshController.endRefreshing();
            //   webViewController?.addJavaScriptHandler(handlerName: "back", callback: (msg){
            //     Navigator.of(context).pop();
            //   });
          },
          onLoadError: (controller, url, code, message) {
            pullToRefreshController.endRefreshing();
          },
          onProgressChanged: (controller, progress) {
            if (progress == 100) {
              pullToRefreshController.endRefreshing();
            }
            setState(() {
              this.progress = progress / 100;
            });
          },
          onUpdateVisitedHistory: (controller, url, androidIsReload) {},
          // onConsoleMessage: (controller, consoleMessage) {
          //   print(consoleMessage);
          // },

        )
    );

  }
}


// import 'dart:io';
//
// import 'package:flutter/material.dart';
// import 'package:textileclothing/widget/Toast.dart';
// import 'package:flutter_inappwebview/flutter_inappwebview.dart';
// import 'package:url_launcher/url_launcher.dart';
//
//
//
//
// class WebViewNewExample extends StatefulWidget {
//   String url;
//   String title = "";
//
//   WebViewNewExample(this.url, this.title);
//
//   @override
//   WebViewExampleState createState() => WebViewExampleState(url, title);
// }
//
// class WebViewExampleState extends State<WebViewNewExample> {
//   String murl = "";
//   String mtitle = "";
//
//   final GlobalKey webViewKey = GlobalKey();
//   InAppWebViewController? webViewController;
//   InAppWebViewGroupOptions options = InAppWebViewGroupOptions(
//       crossPlatform: InAppWebViewOptions(
//         useShouldOverrideUrlLoading: true,
//         mediaPlaybackRequiresUserGesture: false,
//       ),
//       android: AndroidInAppWebViewOptions(
//         useHybridComposition: true,
//       ),
//       ios: IOSInAppWebViewOptions(
//         allowsInlineMediaPlayback: true,
//       ));
//
//   late PullToRefreshController pullToRefreshController;
//   double progress = 0;
//
//   @override
//   void initState() {
//     super.initState();
//     pullToRefreshController = PullToRefreshController(
//       options: PullToRefreshOptions(
//         color: Colors.blue,
//       ),
//       onRefresh: () async {
//         if (Platform.isAndroid) {
//           webViewController?.reload();
//         } else if (Platform.isIOS) {
//           webViewController?.loadUrl(
//               urlRequest: URLRequest(url: Uri.parse(murl)));
//         }
//       },
//     );
//   }
//   WebViewExampleState(this.murl, this.mtitle);
//
//   @override
//   Widget build(BuildContext context) {
//     // Toast.toast(context,msg: "url:"+murl);
//     // return InAppWebView(
//     //   key: webViewKey,
//     //   initialUrlRequest: URLRequest(url: Uri.parse(murl)),
//     //   initialOptions: options,
//     //   pullToRefreshController: pullToRefreshController,
//     //   onWebViewCreated: (controller) {
//     //     webViewController = controller;
//     //   },
//     //   onLoadStart: (controller, url) {
//     //     setState(() {
//     //       murl = url.toString();
//     //     });
//     //   },
//     //   androidOnPermissionRequest: (controller, origin, resources) async {
//     //     return PermissionRequestResponse(
//     //         resources: resources,
//     //         action: PermissionRequestResponseAction.GRANT);
//     //   },
//     //   shouldOverrideUrlLoading: (controller, navigationAction) async {
//     //     var uri = navigationAction.request.url!;
//     //
//     //     if (![
//     //       "http",
//     //       "https",
//     //       "file",
//     //       "chrome",
//     //       "data",
//     //       "javascript",
//     //       "about"
//     //     ].contains(uri.scheme)) {
//     //       if (await canLaunch(murl)) {
//     //         // Launch the App
//     //         await launch(
//     //           murl,
//     //         );
//     //         // and cancel the request
//     //         return NavigationActionPolicy.CANCEL;
//     //       }
//     //     }
//     //
//     //     return NavigationActionPolicy.ALLOW;
//     //   },
//     //   onLoadStop: (controller, url) async {
//     //     pullToRefreshController.endRefreshing();
//     //   },
//     //   onLoadError: (controller, url, code, message) {
//     //     pullToRefreshController.endRefreshing();
//     //   },
//     //   onProgressChanged: (controller, progress) {
//     //     if (progress == 100) {
//     //       pullToRefreshController.endRefreshing();
//     //     }
//     //     setState(() {
//     //       this.progress = progress / 100;
//     //     });
//     //   },
//     //   onUpdateVisitedHistory: (controller, url, androidIsReload) {},
//     //   onConsoleMessage: (controller, consoleMessage) {
//     //     print(consoleMessage);
//     //   },
//     //
//     // );
//      return Scaffold(
//         appBar: AppBar(
//         leading: IconButton(
//           icon: const Icon(Icons.arrow_back, color: Colors.black),
//           onPressed: () {
//             Navigator.of(context).pop("fanhui");
//           },
//         ),
//         iconTheme: const IconThemeData(
//           color: Color(0xff333333), //修改颜色
//         ),
//         title: Text(mtitle),
//         elevation: 0,
//         //去掉阴影
//         centerTitle: true, //是否居中
//       ),
//         body:InAppWebView(
//             key: webViewKey,
//             initialUrlRequest: URLRequest(url: Uri.parse(murl)),
//             initialOptions: options,
//             pullToRefreshController: pullToRefreshController,
//             onWebViewCreated: (controller) {
//               webViewController = controller;
//             },
//             onLoadStart: (controller, url) {
//               setState(() {
//                 murl = url.toString();
//               });
//             },
//             androidOnPermissionRequest: (controller, origin, resources) async {
//               return PermissionRequestResponse(
//                   resources: resources,
//                   action: PermissionRequestResponseAction.GRANT);
//             },
//             shouldOverrideUrlLoading: (controller, navigationAction) async {
//               var uri = navigationAction.request.url!;
//
//               if (![
//                 "http",
//                 "https",
//                 "file",
//                 "chrome",
//                 "data",
//                 "javascript",
//                 "about"
//               ].contains(uri.scheme)) {
//                 if (await canLaunch(murl)) {
//                   // Launch the App
//                   await launch(
//                     murl,
//                   );
//                   // and cancel the request
//                   return NavigationActionPolicy.CANCEL;
//                 }
//               }
//
//               return NavigationActionPolicy.ALLOW;
//             },
//             onLoadStop: (controller, url) async {
//               pullToRefreshController.endRefreshing();
//             },
//             onLoadError: (controller, url, code, message) {
//               pullToRefreshController.endRefreshing();
//             },
//             onProgressChanged: (controller, progress) {
//               if (progress == 100) {
//                 pullToRefreshController.endRefreshing();
//               }
//               setState(() {
//                 this.progress = progress / 100;
//               });
//             },
//             onUpdateVisitedHistory: (controller, url, androidIsReload) {},
//             onConsoleMessage: (controller, consoleMessage) {
//               print(consoleMessage);
//             },
//
//           )
//     );
//
// //     return Scaffold(
// //       appBar: AppBar(
// //         leading: IconButton(
// //           icon: const Icon(Icons.arrow_back, color: Colors.black),
// //           onPressed: () {
// //             Navigator.of(context).pop("fanhui");
// //           },
// //         ),
// //         iconTheme: const IconThemeData(
// //           color: Color(0xff333333), //修改颜色
// //         ),
// //         title: Text(mtitle),
// //         elevation: 0,
// //         //去掉阴影
// //         centerTitle: true, //是否居中
// //       ),
// //       // body: Text("11111111111111111"),
// //       body: Expanded(
// //         child: Stack(children: [
// //           InAppWebView(
// //             key: webViewKey,
// //             initialUrlRequest: URLRequest(url: Uri.parse("www.baidu.com")),
// //             initialOptions: options,
// //             pullToRefreshController: pullToRefreshController,
// //             onWebViewCreated: (controller) {
// //               webViewController = controller;
// //             },
// //             onLoadStart: (controller, url) {
// //               setState(() {
// //                 murl = url.toString();
// //               });
// //             },
// //             androidOnPermissionRequest: (controller, origin, resources) async {
// //               return PermissionRequestResponse(
// //                   resources: resources,
// //                   action: PermissionRequestResponseAction.GRANT);
// //             },
// //             shouldOverrideUrlLoading: (controller, navigationAction) async {
// //               var uri = navigationAction.request.url!;
// //
// //               if (![
// //                 "http",
// //                 "https",
// //                 "file",
// //                 "chrome",
// //                 "data",
// //                 "javascript",
// //                 "about"
// //               ].contains(uri.scheme)) {
// //                 if (await canLaunch(murl)) {
// //                   // Launch the App
// //                   await launch(
// //                     murl,
// //                   );
// //                   // and cancel the request
// //                   return NavigationActionPolicy.CANCEL;
// //                 }
// //               }
// //
// //               return NavigationActionPolicy.ALLOW;
// //             },
// //             onLoadStop: (controller, url) async {
// //               pullToRefreshController.endRefreshing();
// //             },
// //             onLoadError: (controller, url, code, message) {
// //               pullToRefreshController.endRefreshing();
// //             },
// //             onProgressChanged: (controller, progress) {
// //               if (progress == 100) {
// //                 pullToRefreshController.endRefreshing();
// //               }
// //               setState(() {
// //                 this.progress = progress / 100;
// //               });
// //             },
// //             onUpdateVisitedHistory: (controller, url, androidIsReload) {},
// //             onConsoleMessage: (controller, consoleMessage) {
// //               print(consoleMessage);
// //             },
// //           ),
// //           progress < 1.0
// //               ? LinearProgressIndicator(value: progress)
// //               : Container(),
// //         ]
// //     ),
// //       ),
// //     );
//   }
// }
