import 'package:flutter/cupertino.dart';

import 'DioUtils.dart';
import 'apis.dart';

typedef Success<T> = Function(T data);
typedef Fail = Function(int code, String msg);

class HttpUtils {
  static void login<T>(BuildContext context,
      parameters, {
        Success? success,
        Fail? fail,
      }) {
    postJSON(context,APIs.login, parameters, success: success!, fail: fail!);
  }

  //分页加载数据
  static void getNewPageList<T>(BuildContext context,
      parameters, {
        Success? success,
        Fail? fail,
      }) {
    postJSON(context,APIs.getPage, parameters, success: success!, fail: fail!);
  }

  //分页加载分组数据
  static void getNewPageGroupList<T>(BuildContext context,
      parameters, {
        Success? success,
        Fail? fail,
      }) {
    postJSON(context,APIs.getGroupPage, parameters, success: success!, fail: fail!);
  }

  // //GET
  // static void GetRequest<T>(BuildContext context,
  //     APIType apiType,
  //     parameters, {
  //       Success? success,
  //       Fail? fail,
  //     }) {
  //   postJSON(context,APITypeValues[apiType]!, parameters, success: success!, fail: fail!);
  // }
  //
  // //POST
  // static void PostRequest<T>(BuildContext context,
  //     APIType apiType,
  //     parameters, {
  //       Success? success,
  //       Fail? fail,
  //     }) {
  //   postJSON(context,APITypeValues[apiType]!, parameters, success: success!, fail: fail!);
  // }

  /********************************* 分割线 ********************************/

  //get 请求
  static void get<T>(
      String url,
      Type type,
      parameters, {
        Success? success,
        Fail? fail,
      }) {
    _request(Method.GET, url, parameters, success: success!, fail: fail!);
  }

  // //post 请求
  // static void post<T>(
  //   String url,
  //   parameters, {
  //   Success success,
  //   Fail fail,
  // }) {
  //   _request(Method.POST, url, Type.JSON, parameters,
  //       success: success, fail: fail);
  // }

/*  //post 请求
  static void post<T>(
      String url,
      parameters, {
        Success success,
        Fail fail,
        Type type = Type.FORM,
      }) {
    _request(Method.POST, url, parameters,
        success: success, fail: fail, type: type);
  }*/
  static void postJSON<T>( BuildContext context,
      String url,
      parameters, {
        Success? success,
        Fail? fail,
        Type type = Type.FORM,

      }) {
    _requestJSON(Method.POST, url, parameters,
        success: success!, fail: fail!, type: type,context: context);
  }
  //_request 请求
  static void _request<T>(
      Method method,
      String url,
      parameters, {
        Success? success,
        Fail? fail,
        Type? type,
      }) {
    /// restful 请求处理
    /// /base/search/hist/:user_id        user_id=27
    /// 最终生成 url 为     /base/search/hist/27
    parameters.forEach((key, value) {
      if (url.indexOf(key) != -1) {
        url = url.replaceAll(':$key', value.toString());
      }
    });

    DioUtils.request(method, url, parameters, success: (result) {
      if (success != null) {
        success(result);
      }
    }, fail: (code, msg) {
      if (fail != null) {
        fail(code, msg);
      }
    },type: type);
  }

  static void _requestJSON<T>(
      Method method,
      String url,
      parameters, {
        Success? success,
        Fail? fail,
        Type? type,
        BuildContext? context
      }) {
    /// restful 请求处理
    /// /base/search/hist/:user_id        user_id=27
    /// 最终生成 url 为     /base/search/hist/27
    parameters.forEach((key, value) {
      if (url.indexOf(key) != -1) {
        url = url.replaceAll(':$key', value.toString());
      }
    });

    DioUtils.request(method, url, parameters, success: (result) {

      if (success != null) {
        success(result);
      }
    }, fail: (code, msg) {
      if (fail != null) {
        fail(code, msg);
      }
    },type: type,context: context);
  }
}
