import 'dart:collection';
import 'dart:convert';

import 'package:flutter/material.dart';
import 'package:flutter_html/flutter_html.dart';
import 'package:flutter_swiper_plus/flutter_swiper_plus.dart';
import 'package:pull_to_refresh/pull_to_refresh.dart';

import '../Iconfont.dart';
import '../dio/APIs.dart';
import '../dio/HttpUtils.dart';
import '../utils/Global.dart';
import '../utils/TimeUtils.dart';
import '../widget/MySmartRefresher.dart';
import '../widget/StickyTabBarDelegate.dart';
import '../widget/Toast.dart';
import 'HomeSerch.dart';
import 'NewNoticeInfo.dart';

class HomeBody extends StatefulWidget {
  State homeBody = HomeBodyState();
  @override
  State<StatefulWidget> createState() {
    return homeBody;
  }

  void serchClear(){
    (homeBody as HomeBodyState).clearSerchController();
  }

}

class HomeBodyState extends State with TickerProviderStateMixin {
  TextEditingController serchController = TextEditingController();
  // bool isLoading = false;

  bool isRefresh = false;
  RefreshController refreshController = RefreshController();

  int pageNo = 1;
  int pageSize = 15;

  Map datamap = HashMap();
  Map picmap = HashMap();
  Map bannerMap = HashMap();

  @override
  void initState() {
    super.initState();
    serchController.clear();
    readBanner();
    getNewsList();
  }

 void clearSerchController(){
    serchController.clear();
    readBanner();
    getNewsList();
  }

  //获取新闻列表
  getNewsList() async {
    HttpUtils.postJSON(context, APIs.BaseNewsList, {
      "pageNo": pageNo,
      "pageSize": pageSize,
      "channelId": "7,9,10,11,12,14",
      "hasInclude": false,
      "randomKey": "0.33621082370012556",
      "statusKey": "2",
      "keyWords": serchController.text,
      "token": await Global.getData("token"),
      "title": serchController.text
    }, success: (data) async {
      setState(() {
        if (datamap.isNotEmpty && pageNo == datamap["totalPage"]) {
          refreshController.resetNoData();
        } else {
          refreshController.loadComplete();
        }
        refreshController.refreshCompleted();
        isRefresh = true;
        if (pageNo == 1) {
          datamap = data;
        } else {
          datamap["rows"].addAll(data["rows"]);
        }
      });
    }, fail: (code, msg) {});
  }

  void readArticle(String id, bool isLink, String url) async {
    HttpUtils.postJSON(context, APIs.readArticle, {
      "token": await Global.getData("token"),
      "isRead": true,
      "id": id
    }, success: (data) async {
      setState(() {
        if (data) {
          if (isLink) {
            Global.openUrl(context, url, true);
          } else {
            setonTap(id);
          }
        }
      });
    }, fail: (code, msg) {});
  }

  void setonTap(String id) async {
    Global.openUrl(context,
        "/h5View/detail?id=$id&token=${await Global.getData("token")}");
  }

  void readBanner() async {
    HttpUtils.postJSON(context, APIs.readBanner, {
      "token": await Global.getData("token"),
      "isPc": true,
      "pageNo": 1,
      "pageSize": 5,
      "isShelf": true,
      "moduleType": "门户首页",
    }, success: (data) async {
      setState(() {
        bannerMap = data;
      });
    }, fail: (code, msg) {});
  }



  Widget serchWidget() {
    return
        // SliverPersistentHeader(
        //   delegate: StickyTabBarDelegate(
        //     child:
        Container(
      margin: const EdgeInsets.only(left: 10, right: 10, top: 10, bottom: 10),
      child: Row(
        children: <Widget>[
          // Container(
          //   width: 20,
          //   height: 20,
          //   margin: const EdgeInsets.only(bottom: 2),
          //   child: Image.asset(
          //     "images/times.png",
          //   )),
          //因为它是左右占比结构,所以使用Expanded 的flex
          Expanded(
              flex: 1,
              child: Container(
                //所有组件垂直居中
                alignment: Alignment.center,
                height: 40,
                padding: const EdgeInsets.fromLTRB(10, 0, 15, 0),
                margin: const EdgeInsets.fromLTRB(10, 0, 10, 0),
                //带有弧度的边框,有背景色
                decoration: BoxDecoration(
                  //背景
                  color: const Color(0xfff2f2f2),
                  //设置四周圆角 角度
                  borderRadius: const BorderRadius.all(Radius.circular(25.0)),
                  //设置四周边框
                  border: Border.all(
                    width: 1,
                    color: const Color(0xfff2f2f2),
                  ),
                ),
                child: Container(
                  padding: const EdgeInsets.fromLTRB(0, 5, 5, 5),
                  child: TextField(
                  controller: serchController,
                  style: const TextStyle(fontSize: 16),
                  decoration: InputDecoration(
                    hintText: "请输入标题、内容",
                    hintStyle: const TextStyle(color: Color(0x50000000)),
                    border: InputBorder.none,
                    prefixIcon: GestureDetector(
                      child: Container(
                          width: 20,
                          height: 20,
                          padding: const EdgeInsets.fromLTRB(10, 0, 10, 0),
                          child: Image.asset(
                            "images/logo.png",
                          )),
                      // child: const Icon(Iconfont.search,
                      //     color: Color(0x50000000), size: 15),
                      onTap: () {
                    //     getNewsList();
                      },
                    ),
                  ),
                ),)
              )),
          GestureDetector(
            child: const Icon(Iconfont.search,
                color: Color(0x50000000), size: 15),
            onTap: () {
              if (serchController.text.isEmpty) {
                Toasts.showToast("请输入搜索内容");
              }else{
                getNewsList();
              }
            },
          )
        ],
      ),
    );
    // ));
  }

  @override
  Widget build(BuildContext context) {
    return Scaffold(
        backgroundColor: Colors.white,
        appBar: AppBar(
          title: serchWidget(),
          backgroundColor: Colors.white,
          elevation: 0,
          leadingWidth: 0,
          // leading: const Text(""),
        ),
        body: getbody());
  }

  Widget getbody() {
    if (!isRefresh) {
      return Global.add();
    } else {
      return Container(
          margin: const EdgeInsets.only(left: 15, right: 15),
          child: MySmartRefresher().getRefreshers(
            refreshController,
            _onRefresh,
            _onLoading,
            getContent(),
          ));
    }
  }

  Widget getContent() {
    return SingleChildScrollView(
      child: Column(
        children: [
          SizedBox(
            width: MediaQuery.of(context).size.width,
            height: 200.0, //设定高 -- 不指定高，图片会被拉伸
            child: Swiper(
              key: UniqueKey(),
              itemBuilder: (BuildContext context, int index) {
                return Image.network(
                  APIs.imgFile + jsonDecode(bannerMap["rows"][index]["picture"])["filePath"],
                  fit: BoxFit.fill,
                );
              },
              itemCount: bannerMap["rows"].length,
              pagination: const SwiperPagination(
                  builder: DotSwiperPaginationBuilder(
                color: Colors.black54,
                activeColor: Colors.white,
              )),
              control: const SwiperControl(),
              scrollDirection: Axis.horizontal,
              autoplay: true,
              onTap: (i) {
                print("点击了：" + i.toString());
              },
            ),
          ),
          getHinds(),
        ],
      ),
    );
  }

  Widget getHinds() {
    if (!isRefresh) {
      return Global.add();
    } else {
      return Column(
        children: [
          ListView.builder(
              //是list列表
              physics: const NeverScrollableScrollPhysics(),
              shrinkWrap: true,
              itemCount: datamap["rows"].length ?? 0,
              itemBuilder: (BuildContext context, int index) {
                return getNewsGGType(datamap["rows"][index]);
              })
        ],
      );
    }
  }

  //新闻公告列表
  Widget getNewsGGType(Map map) {
    if (map["img"] == null || map["img"] == "") {
      return getList1(
          map["isTop"],
          map["title"],
          map["createTime"],
          map["userName"] ?? map["articleSource"],
          // "${map["viewCount"].toString()} 阅读 ",
          map["id"],
          map["isLink"] ?? false,
          map["linkUrl"] ?? "");
    } else {
      return getList2(
          map["isTop"],
          map["title"],
          map["createTime"],
          map["userName"] ?? map["articleSource"],
          // "${map["viewCount"].toString()} 阅读 ",
          json.decode(map["img"])["url"],
          map["id"],
          map["isLink"] ?? false,
          map["linkUrl"] ?? "");
    }
  }

  Widget getList1(bool isTop, String title, int time, String reder, String id,
      bool isLink, String linkUrl) {
    return GestureDetector(
        child: Column(
          mainAxisAlignment: MainAxisAlignment.start,
          children: [
            Container(
              alignment: Alignment.topLeft,
              margin: const EdgeInsets.only(top: 20, left: 10, right: 10),
              child: Text(
                title,
                overflow: TextOverflow.ellipsis,
                style: const TextStyle(
                    fontSize: 15,
                    color: Color(0xff333333),
                    fontWeight: FontWeight.bold),
              ),
            ),
            Container(
                margin: const EdgeInsets.only(top: 20, left: 10, right: 20),
                child: Row(
                  children: [
                    isTop
                        ?  Text(
                            "置顶  ",
                            style: TextStyle(
                                height: 1.3,
                                fontSize: 13,
                                color:Color(APIs.themeColors),
                                // color:Color(APIs.themeColors),
                                fontWeight: FontWeight.bold),
                          )
                        : const Text(""),
                    Text(reder,
                        style: const TextStyle(
                            height: 1.3,
                            fontSize: 13,
                            color: Color(0xff8e8e8e)),
                        textAlign: TextAlign.right),
                    const Text(
                      "   ",
                      style: TextStyle(
                          height: 1.3, fontSize: 13, color: Color(0xff8e8e8e)),
                    ),
                    Text(
                      time == null
                          ? ""
                          : TimeUtils.timestampToDateStr(time, true),
                      style: const TextStyle(
                          height: 1.3, fontSize: 13, color: Color(0xff8e8e8e)),
                    ),
                  ],
                )),
            Container(
              margin: const EdgeInsets.only(top: 10),
              width: double.infinity,
              height: 0.5,
              color: const Color(0xffE5E5E5),
            ),
          ],
        ),
        onTap: () {
          readArticle(id, isLink, linkUrl);
        });
  }

  Widget getList2(bool isTop, var title, var time, var reder, var path,
      String id, bool isLink, String linkUrl) {
    return GestureDetector(
        child: Column(
          children: [
            Row(
              mainAxisAlignment: MainAxisAlignment.spaceBetween,
              crossAxisAlignment: CrossAxisAlignment.center,
              children: [
                Column(
                  mainAxisAlignment: MainAxisAlignment.start,
                  children: [
                    Container(
                      // width: 280,
                      width: Global.getScale(context) * 220,
                      alignment: Alignment.topLeft,
                      margin: const EdgeInsets.only(
                        top: 10,
                        left: 10,
                      ),
                      child: Text(
                        title ?? "暂无",
                        style: const TextStyle(
                            fontSize: 15,
                            color: Color(0xff333333),
                            fontWeight: FontWeight.bold),
                      ),
                    ),
                    Container(
                        width: Global.getScale(context) * 220,
                        margin: const EdgeInsets.only(
                          top: 10,
                          left: 10,
                        ),
                        child: Row(
                          children: [
                            isTop
                                ?  Text(
                                    "置顶  ",
                                    style: TextStyle(
                                        height: 1.3,
                                        fontSize: 13,
                                        // color: Color(0xff07905F),
                                        color:Color(APIs.themeColors),
                                        fontWeight: FontWeight.bold),
                                  )
                                : const Text(""),
                            Text(reder,
                                style: const TextStyle(
                                    height: 1.3,
                                    fontSize: 13,
                                    color: Color(0xff8e8e8e)),
                                textAlign: TextAlign.right),
                            const Text(
                              "   ",
                              style: TextStyle(
                                  height: 1.3,
                                  fontSize: 13,
                                  color: Color(0xff8e8e8e)),
                            ),
                            Text(
                              time == null
                                  ? ""
                                  : TimeUtils.timestampToDateStr(time, true),
                              style: const TextStyle(
                                  height: 1.3,
                                  fontSize: 13,
                                  color: Color(0xff8e8e8e)),
                            ),
                          ],
                        )),
                  ],
                ),
                Container(
                  padding: const EdgeInsets.only(right: 5, top: 10, bottom: 10),
                  child: Image.network(
                    path,
                    width: Global.getScale(context) * 120,
                    height: Global.getScale(context) * 80,
                    fit: BoxFit.cover,
                  ),
                ),
              ],
            ),
            Container(
              margin: const EdgeInsets.only(top: 10),
              width: double.infinity,
              height: 0.5,
              color: const Color(0xffE5E5E5),
            ),
          ],
        ),
        onTap: () {
          // readArticle(id);
          readArticle(id, isLink, linkUrl);
//          setonTap(id);
        });
  }

  void _onRefresh() async {
    pageNo = 1;
    readBanner();
    getNewsList();
    //下拉刷新获取网络数据
  }

  void _onLoading() async {
    pageNo++;
    getNewsList();
    refreshController.loadComplete();
  }
}

class HomeAppBar extends StatelessWidget {
  @override
  Widget build(BuildContext context) {
    //横向布局
    return Row(
      children: <Widget>[
        //因为它是左右占比结构,所以使用Expanded 的flex
        Expanded(
          flex: 1,
          child: InkWell(
              //利用InkWell组件包裹其他组件,则拥有了点击事件
              onTap: () {
                Navigator.push(context, MaterialPageRoute(builder: (context) {
                  return HomeSerch();
                }));
              },
              child: Container(
                //所有组件垂直居中
                alignment: Alignment.center,
                height: 40,
                padding: const EdgeInsets.fromLTRB(0, 0, 15, 0),
                //带有弧度的边框,有背景色
                decoration: const BoxDecoration(
                  color: Color(0xfff5f5f5),
                ),
                child: Stack(
                  alignment: Alignment.centerLeft,
                  children: <Widget>[
                    const Row(
                      //常用于Row和Column控件
                      children: <Widget>[
                        SizedBox(width: 15), //常用于两个组件之间的分隔
                        Text(
                          '搜索标题、内容',
                          style: TextStyle(color: Colors.black38, fontSize: 15),
                        )
                      ],
                    ),
                    Align(
                      alignment: Alignment.centerRight,
                      child: IconButton(
                        icon: const Icon(Iconfont.search, size: 15),
                        color: Colors.black38,
                        onPressed: () {
                          Navigator.push(context,
                              MaterialPageRoute(builder: (context) {
                            return HomeSerch();
                          }));
                        },
                      ),
                    )
                  ],
                ),
              )),
        ),
      ],
    );
  }
}
