import 'dart:async';
import 'dart:collection';
import 'package:flutter/material.dart';
import 'package:intl/intl.dart';
import 'package:textileclothing/dio/APIs.dart';
import 'package:textileclothing/dio/HttpUtils.dart';
import 'package:textileclothing/widget/Toast.dart';
import 'package:textileclothing/dio/DioUtils.dart';

import 'SetPassword.dart';

class ForgotPassword extends StatefulWidget {
  const ForgotPassword({super.key});

  @override
  State<StatefulWidget> createState() {
    return ForgotPasswordState();
  }
}

class ForgotPasswordState extends State {
  final TextEditingController emailController = TextEditingController();
  final TextEditingController codeController = TextEditingController();

  late Timer _countdownTimer;
  String _codeCountdownStr = '发送验证码';
  int countdownNum = 59;

  void reGetCountdown() {
    setState(() {
      if (_countdownTimer != null) {
        return;
      }
      // Timer的第一秒倒计时是有一点延迟的，为了立刻显示效果可以添加下一行。
      _codeCountdownStr = '${countdownNum--}秒后再次发送';
      _countdownTimer = Timer.periodic(const Duration(seconds: 1), (timer) {
        setState(() {
          if (countdownNum > 0) {
            _codeCountdownStr = '${countdownNum--}秒后再次发送';
          } else {
            _codeCountdownStr = '获取验证码';
            countdownNum = 59;
            _countdownTimer.cancel();
          }
        });
      });
    });
  }
  //获取y验证码
  registerSend(String value) async {
    HttpUtils.postJSON(context, APIs.sendPhoneOrEmail, {
      "str": value,
      "noNeedToken": true
    }, success: (data) async {
      setState(() {
        if (data["data"]!=null&&data["data"]) {
          Toasts.showToast("获取成功！");
        }else{
          Toasts.showToast(data["message"]);
        }
      });
    }, type: Type.JSON, fail: (code, msg) {});
  }

  //验证验证码接口
  checkPhoneOrEmailLogin(String code) async {
    HttpUtils.postJSON(context, APIs.checkPhoneOrEmailLogin, {
      "code": code,
      "noNeedToken": true,
      "str": emailController.text
    }, success: (data) async {
      setState(() {
        if (data["state"]==200&&data["code"] == "0") {
          APIs.userId = data["data"]["userId"];
          Navigator.push(context,
              MaterialPageRoute(builder: (context) {
                return const SetPassword();
              }));
          // Navigator.push(context,
          //     MaterialPageRoute(builder: (context) {
          //       return  SetPassword();
          //     }));
          // Navigator.of(context).pop();// 关闭对话框
        }else{
          Toasts.showToast(data["message"]);
        }
      });
    }, type: Type.JSON, fail: (code, msg) {});
  }

  @override
  void initState() {
    super.initState();
  }

  @override
  Widget build(BuildContext context) {
    return Scaffold(
      appBar: AppBar(
        title: const Text(
          "忘记密码",
          style: TextStyle(color: Colors.black),
        ),
        backgroundColor: Colors.white,
        elevation: 0,
        leading: IconButton(
          icon: const Icon(
            Icons.arrow_back,
            color: Colors.black,
          ),
          onPressed: () {
            Navigator.pop(context);
          },
        ),
      ),
      backgroundColor: Colors.white,
      body: getconentNo(),
    );
  }
  Future<DateTime?> selectDate(BuildContext context) async {
    DateTime? picked = await showDatePicker(
        context: context,
        initialDate: DateTime.now(),
        firstDate: DateTime(1960),
        lastDate: DateTime(2030)
    );
    return picked;
  }

  //界面内容
  Widget getconentNo() {
    return SingleChildScrollView(
      child: Container(
          alignment: Alignment.topCenter,
          child: Column(
            children: [
              GestureDetector(
                child: Row(
                  children: [
                    getTextStyle14("电子邮箱"),
                    setTextField(emailController, "请输入")
                  ],
                ),
                onTap: () {
                },
              ),
              getLine(),
              GestureDetector(
                child: Row(
                  children: [
                    getTextStyle14("邮箱验证码"),
                    setTextField(codeController, "请输入"),
                    Text(_codeCountdownStr),
                  ],
                ),
                onTap: () {

                  // reGetCountdown();
                  emailController.text.isEmpty?
                  Toasts.showToast("请输入邮箱号"):
                  registerSend(emailController.text);
                  },
              ),
              Container(
                margin: const EdgeInsets.only(
                    left: 10, top: 20, bottom: 20, right: 10),
                child: Container(
                  //边框设置
                    decoration: BoxDecoration(
                      //背景
                      color: const Color(0xff00946B),
                      //设置四周圆角 角度
                      borderRadius:
                      const BorderRadius.all(Radius.circular(25.0)),
                      //设置四周边框
                      border: Border.all(
                        width: 1,
                        color: const Color(0xff00946B),
                      ),
                      // width: 1, color: Colors.white70),
                    ),
                    // margin: const EdgeInsets.only(left: 10, right: 10, bottom: 20),
                    padding: const EdgeInsets.all(10),
                    width: double.infinity,
                    child: GestureDetector(
                      child: const Text(
                        "下一步",
                        style: TextStyle(color: Colors.white),
                        textAlign: TextAlign.center,
                      ),
                      onTap: () {
                        if (codeController.text.isEmpty) {
                          Toasts.showToast("请输入验证码");
                        }else {
                          checkPhoneOrEmailLogin(codeController.text);
                        }
                      },
                    )),
              )
            ],
          )),
    );
  }

  static Widget getLine() {
    return Container(
      margin: const EdgeInsets.only(left: 20, right: 20, top: 10),
      width: double.infinity,
      height: 0.5,
      color: const Color(0xffE5E5E5),
    );
  }

  static Widget getTextStyle14(String name) {
    return Container(
      width: 100,
      margin: const EdgeInsets.only(left: 20, top: 10),
      child: Row(
        children: [
          Text(
            name,
            style: const TextStyle(fontSize: 16, color: Color(0xff333333)),
          )
        ],
      ),
    );
  }

  //右侧输入框
  static Widget setTextField(
      TextEditingController phoneController, String content) {
    if (content != "请输入") {
      phoneController.text = content;
    }
    return Expanded(
        flex: 1,
        child: Container(
            width: double.infinity,
            margin: const EdgeInsets.only(left: 20, top: 10),
            child:Container(
              width: double.infinity,
              margin: const EdgeInsets.only(left: 0, top: 10, right: 20, bottom: 0),
              child: TextField(
                keyboardType: TextInputType.number, //数字键盘
                maxLines: 1,
                controller: phoneController,
                decoration: InputDecoration(
                    hintText: content,
                    border: InputBorder.none,
                    hintStyle: const TextStyle(color: Color(0xff999999), fontSize: 14)),
              ),
            )
        )
    );

  }

  static Widget getTextStyle14conent(String name) {
    return Container(
      margin: const EdgeInsets.only(left: 0, top: 10, right: 20, bottom: 0),
      padding: const EdgeInsets.only(left: 0, top: 10, right: 0, bottom: 10),
      child: Padding(
          padding: const EdgeInsets.only(right: 10),
          child: Text(
            name,
            style: const TextStyle(fontSize: 14, color: Color(0xff999999)),
          )),
    );
  }

}
